<?php
/**
 * Post Settings
 *
 * @package Newsblock
 */

CSCO_Kirki::add_section(
	'post_settings',
	array(
		'title'    => esc_html__( 'Post Settings', 'newsblock' ),
		'priority' => 50,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'        => 'collapsible',
		'settings'    => 'post_collapsible_common',
		'section'     => 'post_settings',
		'label'       => esc_html__( 'Common', 'newsblock' ),
		'priority'    => 10,
		'input_attrs' => array(
			'collapsed' => true,
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'radio',
		'settings' => 'post_sidebar',
		'label'    => esc_html__( 'Default Sidebar', 'newsblock' ),
		'section'  => 'post_settings',
		'default'  => 'right',
		'priority' => 10,
		'choices'  => array(
			'right'    => esc_html__( 'Right Sidebar', 'newsblock' ),
			'left'     => esc_html__( 'Left Sidebar', 'newsblock' ),
			'disabled' => esc_html__( 'No Sidebar', 'newsblock' ),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'multicheck',
		'settings' => 'post_meta',
		'label'    => esc_html__( 'Post Meta', 'newsblock' ),
		'section'  => 'post_settings',
		'default'  => array( 'category', 'date', 'author', 'views', 'shares', 'reading_time' ),
		'priority' => 10,
		'choices'  => apply_filters(
			'csco_post_meta_choices',
			array(
				'category'     => esc_html__( 'Category', 'newsblock' ),
				'date'         => esc_html__( 'Date', 'newsblock' ),
				'author'       => esc_html__( 'Author', 'newsblock' ),
				'views'        => esc_html__( 'Views', 'newsblock' ),
				'shares'       => esc_html__( 'Shares', 'newsblock' ),
				'comments'     => esc_html__( 'Comments', 'newsblock' ),
				'reading_time' => esc_html__( 'Reading Time', 'newsblock' ),
			)
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'checkbox',
		'settings'        => 'post_meta_author_avatar',
		'label'           => esc_html__( 'Display avatar in post meta author', 'newsblock' ),
		'section'         => 'post_settings',
		'default'         => true,
		'priority'        => 10,
		'active_callback' => array(
			array(
				'setting'  => 'post_meta',
				'operator' => 'in',
				'value'    => 'author',
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'radio',
		'settings' => 'post_header_type',
		'label'    => esc_html__( 'Default Page Header Type', 'newsblock' ),
		'section'  => 'post_settings',
		'default'  => 'simple',
		'priority' => 10,
		'choices'  => array(
			'simple'        => esc_html__( 'Simple', 'newsblock' ),
			'standard'      => esc_html__( 'Standard', 'newsblock' ),
			'overlay'       => esc_html__( 'Overlay', 'newsblock' ),
			'large'         => esc_html__( 'Large', 'newsblock' ),
			'large_overlay' => esc_html__( 'Large Overlay', 'newsblock' ),
			'title'         => esc_html__( 'Page Title Only', 'newsblock' ),
			'none'          => esc_html__( 'None', 'newsblock' ),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'radio',
		'settings'        => 'post_media_preview',
		'label'           => esc_html__( 'Standard Page Header Preview', 'newsblock' ),
		'section'         => 'post_settings',
		'default'         => 'cropped',
		'priority'        => 10,
		'choices'         => array(
			'cropped'   => esc_html__( 'Display Cropped Image', 'newsblock' ),
			'uncropped' => esc_html__( 'Display Preview in Original Ratio', 'newsblock' ),
		),
		'active_callback' => array(
			array(
				'setting'  => 'post_header_type',
				'operator' => '==',
				'value'    => 'standard',
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'checkbox',
		'settings' => 'post_subtitle',
		'label'    => esc_html__( 'Display excerpt as post subtitle', 'newsblock' ),
		'section'  => 'post_settings',
		'default'  => true,
		'priority' => 10,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'checkbox',
		'settings' => 'post_author',
		'label'    => esc_html__( 'Display post author', 'newsblock' ),
		'section'  => 'post_settings',
		'default'  => false,
		'priority' => 10,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'checkbox',
		'settings' => 'post_tags',
		'label'    => esc_html__( 'Display tags', 'newsblock' ),
		'section'  => 'post_settings',
		'default'  => true,
		'priority' => 10,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'checkbox',
		'settings' => 'post_comments_simple',
		'label'    => esc_html__( 'Display comments without the View Comments button', 'newsblock' ),
		'section'  => 'post_settings',
		'default'  => false,
		'priority' => 10,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'collapsible',
		'settings' => 'post_collapsible_prev_next',
		'section'  => 'post_settings',
		'label'    => esc_html__( 'Prev Next Links', 'newsblock' ),
		'priority' => 10,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'checkbox',
		'settings' => 'post_prev_next',
		'label'    => esc_html__( 'Display prev next links', 'newsblock' ),
		'section'  => 'post_settings',
		'default'  => false,
		'priority' => 10,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'radio',
		'settings'        => 'post_prev_next_layout',
		'label'           => esc_html__( 'Layout', 'newsblock' ),
		'section'         => 'post_settings',
		'default'         => 'type-1',
		'priority'        => 10,
		'choices'         => array(
			'type-1' => esc_html__( 'Type 1', 'newsblock' ),
			'type-2' => esc_html__( 'Type 2', 'newsblock' ),
		),
		'active_callback' => array(
			array(
				'setting'  => 'post_prev_next',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'select',
		'settings'        => 'post_prev_next_image_orientation',
		'label'           => esc_html__( 'Image Orientation', 'newsblock' ),
		'section'         => 'post_settings',
		'default'         => 'square',
		'choices'         => array(
			'original'       => esc_html__( 'Original', 'newsblock' ),
			'landscape'      => esc_html__( 'Landscape 4:3', 'newsblock' ),
			'landscape-3-2'  => esc_html__( 'Landscape 3:2', 'newsblock' ),
			'landscape-16-9' => esc_html__( 'Landscape 16:9', 'newsblock' ),
			'portrait'       => esc_html__( 'Portrait 3:4', 'newsblock' ),
			'portrait-2-3'   => esc_html__( 'Portrait 2:3', 'newsblock' ),
			'square'         => esc_html__( 'Square', 'newsblock' ),
		),
		'priority'        => 10,
		'active_callback' => array(
			array(
				'setting'  => 'post_prev_next',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'select',
		'settings'        => 'post_prev_next_image_size',
		'label'           => esc_html__( 'Image Size', 'newsblock' ),
		'section'         => 'post_settings',
		'default'         => 'csco-small',
		'choices'         => csco_get_list_available_image_sizes(),
		'priority'        => 10,
		'active_callback' => array(
			array(
				'setting'  => 'post_prev_next',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'dimension',
		'settings'        => 'post_prev_next_image_border_radius',
		'label'           => esc_html__( 'Image Border Radius', 'newsblock' ),
		'section'         => 'post_settings',
		'default'         => '50%',
		'priority'        => 10,
		'output'          => array(
			array(
				'element'  => '.cs-entry__prev-next',
				'property' => '--cs-image-border-radius',
				'suffix'   => '!important',
			),
		),
		'active_callback' => array(
			array(
				'setting'  => 'post_prev_next',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'multicheck',
		'settings'        => 'post_prev_next_meta',
		'label'           => esc_html__( 'Post Meta', 'newsblock' ),
		'section'         => 'post_settings',
		'default'         => array( 'author', 'views' ),
		'priority'        => 10,
		'choices'         => apply_filters(
			'csco_post_meta_choices',
			array(
				'category'     => esc_html__( 'Category', 'newsblock' ),
				'date'         => esc_html__( 'Date', 'newsblock' ),
				'author'       => esc_html__( 'Author', 'newsblock' ),
				'views'        => esc_html__( 'Views', 'newsblock' ),
				'shares'       => esc_html__( 'Shares', 'newsblock' ),
				'comments'     => esc_html__( 'Comments', 'newsblock' ),
				'reading_time' => esc_html__( 'Reading Time', 'newsblock' ),
			)
		),
		'active_callback' => array(
			array(
				'setting'  => 'post_prev_next',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'checkbox',
		'settings'        => 'post_prev_next_meta_author_avatar',
		'label'           => esc_html__( 'Display avatar in post meta author', 'newsblock' ),
		'section'         => 'post_settings',
		'default'         => true,
		'priority'        => 10,
		'active_callback' => array(
			array(
				'setting'  => 'post_prev_next',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'post_prev_next_meta',
				'operator' => 'in',
				'value'    => 'author',
			),
		),
	)
);

if ( csco_powerkit_module_enabled( 'opt_in_forms' ) ) {
	CSCO_Kirki::add_field(
		'csco_theme_mod',
		array(
			'type'     => 'collapsible',
			'settings' => 'post_collapsible_subscription_form',
			'section'  => 'post_settings',
			'label'    => esc_html__( 'Subscription Form', 'newsblock' ),
			'priority' => 10,
		)
	);

	CSCO_Kirki::add_field(
		'csco_theme_mod',
		array(
			'type'     => 'checkbox',
			'settings' => 'post_subscribe',
			'label'    => esc_html__( 'Display subscribe section', 'newsblock' ),
			'section'  => 'post_settings',
			'default'  => false,
			'priority' => 10,
		)
	);

	CSCO_Kirki::add_field(
		'csco_theme_mod',
		array(
			'type'            => 'checkbox',
			'settings'        => 'post_subscribe_name',
			'label'           => esc_html__( 'Display first name field', 'newsblock' ),
			'section'         => 'post_settings',
			'default'         => false,
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'post_subscribe',
					'operator' => '==',
					'value'    => true,
				),
			),
		)
	);

	CSCO_Kirki::add_field(
		'csco_theme_mod',
		array(
			'type'            => 'text',
			'settings'        => 'post_subscribe_title',
			'label'           => esc_html__( 'Title', 'newsblock' ),
			'section'         => 'post_settings',
			'default'         => esc_html__( 'Subscribe to Our Newsletter', 'newsblock' ),
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'post_subscribe',
					'operator' => '==',
					'value'    => true,
				),
			),
		)
	);

	CSCO_Kirki::add_field(
		'csco_theme_mod',
		array(
			'type'              => 'text',
			'settings'          => 'post_subscribe_text',
			'label'             => esc_html__( 'Text', 'newsblock' ),
			'section'           => 'post_settings',
			'default'           => esc_html__( 'Get notified of the best deals on our WordPress themes.', 'newsblock' ),
			'priority'          => 10,
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => array(
				array(
					'setting'  => 'post_subscribe',
					'operator' => '==',
					'value'    => true,
				),
			),
		)
	);
}

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'collapsible',
		'settings' => 'post_collapsible_related_posts',
		'section'  => 'post_settings',
		'label'    => esc_html__( 'Related Posts', 'newsblock' ),
		'priority' => 10,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'checkbox',
		'settings' => 'related',
		'label'    => esc_html__( 'Display related section', 'newsblock' ),
		'section'  => 'post_settings',
		'default'  => true,
		'priority' => 10,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'select',
		'settings'        => 'related_image_orientation',
		'label'           => esc_html__( 'Image Orientation', 'newsblock' ),
		'section'         => 'post_settings',
		'default'         => 'original',
		'choices'         => array(
			'original'       => esc_html__( 'Original', 'newsblock' ),
			'landscape'      => esc_html__( 'Landscape 4:3', 'newsblock' ),
			'landscape-3-2'  => esc_html__( 'Landscape 3:2', 'newsblock' ),
			'landscape-16-9' => esc_html__( 'Landscape 16:9', 'newsblock' ),
			'portrait'       => esc_html__( 'Portrait 3:4', 'newsblock' ),
			'portrait-2-3'   => esc_html__( 'Portrait 2:3', 'newsblock' ),
			'square'         => esc_html__( 'Square', 'newsblock' ),
		),
		'priority'        => 10,
		'active_callback' => array(
			array(
				'setting'  => 'related',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'select',
		'settings'        => 'related_image_size',
		'label'           => esc_html__( 'Image Size', 'newsblock' ),
		'section'         => 'post_settings',
		'default'         => 'csco-thumbnail-small',
		'choices'         => csco_get_list_available_image_sizes(),
		'priority'        => 10,
		'active_callback' => array(
			array(
				'setting'  => 'related',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'multicheck',
		'settings'        => 'related_post_meta',
		'label'           => esc_html__( 'Post Meta', 'newsblock' ),
		'section'         => 'post_settings',
		'default'         => array( 'category', 'author', 'views', 'shares' ),
		'priority'        => 10,
		'choices'         => apply_filters(
			'csco_post_meta_choices',
			array(
				'category'     => esc_html__( 'Category', 'newsblock' ),
				'date'         => esc_html__( 'Date', 'newsblock' ),
				'author'       => esc_html__( 'Author', 'newsblock' ),
				'views'        => esc_html__( 'Views', 'newsblock' ),
				'shares'       => esc_html__( 'Shares', 'newsblock' ),
				'comments'     => esc_html__( 'Comments', 'newsblock' ),
				'reading_time' => esc_html__( 'Reading Time', 'newsblock' ),
			)
		),
		'active_callback' => array(
			array(
				'setting'  => 'related',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'number',
		'settings'        => 'related_number',
		'label'           => esc_html__( 'Maximum Number of Related Posts', 'newsblock' ),
		'section'         => 'post_settings',
		'default'         => 4,
		'priority'        => 10,
		'choices'     => array(
			'min'  => 4,
			'max'  => 16,
			'step' => 4,
		),
		'input_attrs' => array(
			'readonly' => '',
		),
		'active_callback' => array(
			array(
				'setting'  => 'related',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

if ( csco_post_views_enabled() ) {

	CSCO_Kirki::add_field(
		'csco_theme_mod',
		array(
			'type'            => 'radio',
			'settings'        => 'related_orderby',
			'label'           => esc_html__( 'Order posts by', 'newsblock' ),
			'section'         => 'post_settings',
			'default'         => 'rand',
			'priority'        => 10,
			'choices'         => array(
				'rand'       => esc_html__( 'Rand', 'newsblock' ),
				'date'       => esc_html__( 'Date', 'newsblock' ),
				'post_views' => esc_html__( 'Views', 'newsblock' ),
			),
			'active_callback' => array(
				array(
					'setting'  => 'related',
					'operator' => '==',
					'value'    => true,
				),
			),
		)
	);

	CSCO_Kirki::add_field(
		'csco_theme_mod',
		array(
			'type'            => 'text',
			'settings'        => 'related_time_frame',
			'label'           => esc_html__( 'Time Frame', 'newsblock' ),
			'description'     => esc_html__( 'Add period of posts in English. For example: &laquo;2 months&raquo;, &laquo;14 days&raquo; or even &laquo;1 year&raquo;', 'newsblock' ),
			'section'         => 'post_settings',
			'default'         => '',
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'related',
					'operator' => '==',
					'value'    => true,
				),
				array(
					'setting'  => 'related_orderby',
					'operator' => '==',
					'value'    => 'post_views',
				),
			),
		)
	);
}

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'collapsible',
		'settings' => 'post_collapsible_load_nextpost',
		'section'  => 'post_settings',
		'label'    => esc_html__( 'Auto Load Next Post', 'newsblock' ),
		'priority' => 10,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'checkbox',
		'settings' => 'post_load_nextpost',
		'label'    => esc_html__( 'Enable the Auto Load Next Post feature', 'newsblock' ),
		'section'  => 'post_settings',
		'default'  => false,
		'priority' => 10,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'checkbox',
		'settings'        => 'post_load_nextpost_same_category',
		'label'           => esc_html__( 'Auto load posts from the same category only', 'newsblock' ),
		'section'         => 'post_settings',
		'default'         => false,
		'priority'        => 10,
		'active_callback' => array(
			array(
				'setting'  => 'post_load_nextpost',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'checkbox',
		'settings'        => 'post_load_nextpost_reverse',
		'label'           => esc_html__( 'Auto load previous posts instead of next ones', 'newsblock' ),
		'section'         => 'post_settings',
		'default'         => false,
		'priority'        => 10,
		'active_callback' => array(
			array(
				'setting'  => 'post_load_nextpost',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);
